@@ -8,6 +8,13 @@
 ## ------------------------------------------------------------------------
 library(sparsevar)
 
+## ---- cache = TRUE-------------------------------------------------------
+set.seed(1)
+sim <- simulateVAR(N = 20, p = 2)
+
+## ---- cache = TRUE-------------------------------------------------------
+fit <- fitVAR(sim$series, p = 2)
+
 ## ------------------------------------------------------------------------
 plotVAR(sim, fit)
 
